@@ -1,5 +1,5 @@
 from severino.sdk.airflow import Airflow
-from severino.sdk.hub_distance import HubDistance
+from severino.sdk.hub_distance import HubDistance, HubDistanceCEP
 from severino.sdk.internal_recruitment import MindsightReminder, Movement, Stage
 from severino.sdk.mail_carrier import MailCarrier
 from severino.sdk.reports_of_pcds_in_admission import ReminderReportsOfPcdsInAdmission
